@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -108,7 +108,7 @@ __PACKAGE__->add_property( 'alien_provides_libs' );
 #   |-- platform: src or platform, matching os_type M::B method
 #   |
 #   |-- (non-api) connection: holder for Net::FTP-like object (needs cwd, ls, and get methods)
-__PACKAGE__->add_property( 'alien_repository'         => {} );
+__PACKAGE__->add_property( 'alien_repository'         => [] );
 __PACKAGE__->add_property( 'alien_repository_default' => {} );
 __PACKAGE__->add_property( 'alien_repository_class'   => {} );
 
@@ -225,6 +225,23 @@ END
 #  ACTION methods  #
 ####################
 
+sub ACTION_alien_fakebuild {
+  my $self = shift;
+
+  print "# Build\n";
+  foreach my $cmd (@{ $self->alien_build_commands })
+  {
+    my @cmd = map { $self->alien_interpolate($_) } ref($cmd) ? @$cmd : ($cmd);
+    print "+ @cmd\n";
+  }
+  print "# Build install\n";
+  foreach my $cmd (@{ $self->alien_install_commands })
+  {
+    my @cmd = map { $self->alien_interpolate($_) } ref($cmd) ? @$cmd : ($cmd);
+    print "+ @cmd\n";
+  }
+}
+
 sub ACTION_code {
   my $self = shift;
   $self->notes( 'alien_blib_scheme' => $self->alien_detect_blib_scheme );
@@ -341,6 +358,10 @@ sub ACTION_alien_code {
   }
 
   if (! $version and ! $pc_version) {
+    print STDERR "If you are the author of this Alien dist, you may need to provide a an\n";
+    print STDERR "alien_check_built_version method for your Alien::Base::ModuleBuild\n";
+    print STDERR "class.  See:\n";
+    print STDERR "https://metacpan.org/pod/Alien::Base::ModuleBuild#alien_check_built_version\n";
     carp "Library looks like it installed, but no version was determined";
     $self->config_data( version => 0 );    
     return
@@ -475,6 +496,14 @@ sub alien_create_repositories {
   if (ref $repo_specs eq 'HASH') {
     $repo_specs = [ $repo_specs ];
   }
+  
+  unless(@$repo_specs)
+  {
+    print STDERR "If you are the author of this Alien dist, you need to provide at least\n";
+    print STDERR "one repository in your Build.PL.  See:\n";
+    print STDERR "https://metacpan.org/pod/distribution/Alien-Base/lib/Alien/Base/ModuleBuild/API.pod#alien_repository\n";
+    croak "No repositories specified.";
+  }
 
   my @repos;
   foreach my $repo ( @$repo_specs ) {
